@@ -1,4 +1,4 @@
-from .GroupOptimizations3 import (
+from .optimizr import (
     binarize_groups,
     binarize_target_group,
     find_optimal_groups
